@@ -1,4 +1,4 @@
-__version__ = '0.2.11'
+__version__ = '0.2.14'
 # Copyright (c) 2013. SlickLog.
 __author__ = 'Torindo Nesci'
 
@@ -154,7 +154,7 @@ class SlickLogRemoteLogger:
     try:
       bytes = u(message).encode(SlickLogRemoteLogger.__CHAR_ENCODING)
       self.log_queue.put_nowait(bytes)
-      log('message put int queue: {0}', message)
+      log('message put int queue: {0}', bytes)
     except queue_mod().Full as ex:
       log('Log queue is full, cleaning: {0}.', str(ex))
       with self.log_queue.mutex:
